@@ -71,8 +71,7 @@ class DownloadHandlers:
         scheme = urlparse_cached(request).scheme
         handler = self._get_handler(scheme)
         if not handler:
-            raise NotSupported("Unsupported URL scheme '%s': %s" %
-                               (scheme, self._notconfigured[scheme]))
+            raise NotSupported(f"Unsupported URL scheme '{scheme}': {self._notconfigured[scheme]}")
         return handler.download_request(request, spider)
 
     @defer.inlineCallbacks
