@@ -3,7 +3,7 @@
 from scrapy import signals
 
 
-class UserAgentMiddleware(object):
+class UserAgentMiddleware:
     """This middleware allows spiders to override the user_agent"""
 
     def __init__(self, user_agent='Scrapy'):
