@@ -4,8 +4,19 @@ Transitional module for moving to the w3lib library.
 For new code, always import from w3lib.http instead of this module
 """
 
-from w3lib.http import *
+import warnings
 
+from scrapy.exceptions import ScrapyDeprecationWarning
+from scrapy.utils.decorators import deprecated
+from w3lib.http import *  # noqa: F401
+
+
+warnings.warn("Module `scrapy.utils.http` is deprecated, "
+              "Please import from `w3lib.http` instead.",
+              ScrapyDeprecationWarning, stacklevel=2)
+
+
+@deprecated
 def decode_chunked_transfer(chunked_body):
     """Parsed body received with chunked transfer encoding, and return the
     decoded body.
@@ -21,6 +32,5 @@ def decode_chunked_transfer(chunked_body):
             break
         size = int(h, 16)
         body += t[:size]
-        t = t[size+2:]
+        t = t[size + 2:]
     return body
-
