@@ -17,7 +17,7 @@ class ScrapyJSONEncoder(json.JSONEncoder):
         if isinstance(o, set):
             return list(o)
         elif isinstance(o, datetime.datetime):
-            return o.strftime("%s %s" % (self.DATE_FORMAT, self.TIME_FORMAT))
+            return o.strftime(f"{self.DATE_FORMAT} {self.TIME_FORMAT}")
         elif isinstance(o, datetime.date):
             return o.strftime(self.DATE_FORMAT)
         elif isinstance(o, datetime.time):
@@ -29,11 +29,11 @@ class ScrapyJSONEncoder(json.JSONEncoder):
         elif is_item(o):
             return ItemAdapter(o).asdict()
         elif isinstance(o, Request):
-            return "<%s %s %s>" % (type(o).__name__, o.method, o.url)
+            return f"<{type(o).__name__} {o.method} {o.url}>"
         elif isinstance(o, Response):
-            return "<%s %s %s>" % (type(o).__name__, o.status, o.url)
+            return f"<{type(o).__name__} {o.status} {o.url}>"
         else:
-            return super(ScrapyJSONEncoder, self).default(o)
+            return super().default(o)
 
 
 class ScrapyJSONDecoder(json.JSONDecoder):
