@@ -23,10 +23,10 @@ class ProcessTest:
 
     def _process_finished(self, pp, cmd, check_code):
         if pp.exitcode and check_code:
-            msg = "process %s exit with code %d" % (cmd, pp.exitcode)
-            msg += "\n>>> stdout <<<\n%s" % pp.out
+            msg = f"process {cmd} exit with code {pp.exitcode}"
+            msg += f"\n>>> stdout <<<\n{pp.out}"
             msg += "\n"
-            msg += "\n>>> stderr <<<\n%s" % pp.err
+            msg += f"\n>>> stderr <<<\n{pp.err}"
             raise RuntimeError(msg)
         return pp.exitcode, pp.out, pp.err
 
